@@ -1141,8 +1141,8 @@ azure_prepare_target_versions(KeyVal *env)
 
 	/* default values */
 	sformat(env->values[0], MAXCONNINFO, "13");   /* AZ_PG_VERSION */
-	sformat(env->values[1], MAXCONNINFO, "2.0");  /* AZ_PGAF_DEB_VERSION */
-	sformat(env->values[2], MAXCONNINFO, "2.0-1"); /* AZ_PGAF_DEB_REVISION */
+	sformat(env->values[1], MAXCONNINFO, "2.1");  /* AZ_PGAF_DEB_VERSION */
+	sformat(env->values[2], MAXCONNINFO, "2.1-1"); /* AZ_PGAF_DEB_REVISION */
 
 	for (int i = 0; i < 3; i++)
 	{
@@ -1585,9 +1585,9 @@ azure_fetch_resource_list(const char *group, AzureRegionResources *azRegion)
 			}
 			else if (streq(type, "Microsoft.Compute/virtualMachines"))
 			{
-				int index = azure_node_index_from_name(group, name);
+				int idx = azure_node_index_from_name(group, name);
 
-				strlcpy(azRegion->vmArray[index].name, name, NAMEDATALEN);
+				strlcpy(azRegion->vmArray[idx].name, name, NAMEDATALEN);
 
 				log_info("Found existing VM \"%s\"", name);
 			}
